#include "WindowMapping.h"
#include <stdio.h>


void WindowMapping::GetWorldCoordinates(float &x, float &y)
{
	//map from rectangular physical window to world space.
	float fractionX = (x - bitmapWindow.left) / (m_bitmapWidth);
	float fractionY = (y - bitmapWindow.top) / (m_bitmapHeight);

	x = spaceWindow.left + m_windowWidth*fractionX;
	y = spaceWindow.top + m_windowHeight*fractionY;
}


WindowMapping::WindowMapping()
{
	spaceWindow.bottom = spaceWindow.left = spaceWindow.right = spaceWindow.top = 0.0f;
	bitmapWindow.bottom = bitmapWindow.left = bitmapWindow.right = bitmapWindow.top = 0.0f;
	m_bitmapWidth = m_bitmapHeight = m_windowWidth = m_windowHeight = 0.0f;
}

void WindowMapping::SetWorldWindow(float top, float right, float left, float bottom)
{
	assert(right > left);
	assert(bottom > top);

	spaceWindow.top = top;
	spaceWindow.bottom = bottom;
	spaceWindow.right = right;
	spaceWindow.left = left;

	m_windowWidth = right - left;
	m_windowHeight = bottom - top;
}

//sets where the physical bitmap is stationed
void WindowMapping::SetPhysicalWindow(float top, float right, float left, float bottom)
{
	assert(right > left);
	assert(bottom > top);

	bitmapWindow.top = top;
	bitmapWindow.bottom = bottom;
	bitmapWindow.right = right;
	bitmapWindow.left = left;

	m_bitmapWidth = right - left;
	m_bitmapHeight = bottom - top;
}

WindowMapping::~WindowMapping()
{
}

float WindowMapping::GetSpaceWidth()
{
	return m_windowWidth;
}

float WindowMapping::GetSpaceHeight()
{
	return m_windowHeight;
}